<?php

# FitGallery 0.81 copyleft GPL Pollo (magura@ardilla.dyndns.org) y Presi (presi@confluencia.net)
# http://fitgallery.presi.org

# thumb generator file

function thumbnail ($galeria,$valor,$horiz,$tipo)
{

include 'config/config-thumb.php';

$dg=$dirgal."/".basename($galeria);
switch ($tipo)
{ 
  case "m": $rutathumbs=$dg."/"."medium"; break;
  case "t": $rutathumbs=$dg."/"."thumbs"; break;
  default: echo "Bad type.";
}
$fichero=basename($valor);
$ext=".jpeg";
$imagenthumb=$rutathumbs."/".$fichero.$ext;

if (file_exists($imagenthumb)) header("Location: $imagenthumb");
else
{
  $rutaimgs=$dg."/"."imgs";
  $imagen=$rutaimgs."/".$fichero;

  if ($horiz>$limite_horiz) $horiz=$limite_horiz;

  $size=getimagesize("$imagen");
  $new_w=$horiz*$size[0]/$size[1];
  $new_h=$horiz;

  $dst_img=ImageCreateTrueColor($new_w,$new_h);
  switch ($size[2])
  {
   case 2: $src_img=ImageCreateFromJpeg($imagen); break;
   case 3: $src_img=ImageCreateFromPng($imagen); break;
   default: echo "FitGallery: Source image not in JPEG or PNG.";
  }

  ImageCopyResized($dst_img,$src_img,0,0,0,0,$new_w,$new_h,ImageSX($src_img),ImageSY($src_img));

  header("Content-type: image/jpeg");
  ImageJpeg($dst_img);

  ImageJpeg($dst_img,$imagenthumb);

  Imagedestroy($dst_img);
}

}

thumbnail ($_GET["galeria"],$_GET["valor"],$_GET["horiz"],$_GET["tipo"]);

?>
